@@ -57,6 +57,18 @@ $cmd =~ s/\\/\\\\/g;
 $cmd = "cd qgvdial-$qver & perl build-files/version.pl __QTDIR__ $cmd";
 system($cmd);
 
+# Mixpanel replacement
+open my $mixpanel_token_file, '<', "../mixpanel.token";
+my $mixpanel_token = <$mixpanel_token_file>;
+close $mixpanel_token_file;
+chomp $mixpanel_token;
+$cmd = "perl version.pl __MY_MIXPANEL_TOKEN__ '$mixpanel_token' $basedir";
+print "$cmd\n";
+system($cmd);
+$cmd = "perl version.pl MIXPANEL_TOKEN_INVALID MIXPANEL_TOKEN_VALID $basedir";
+print "$cmd\n";
+system($cmd);
+
 # Compile it!
 $cmd = "cd qgvdial-$qver/qgvdial/qt-not-qml/desktop_windows & qmake ../desktop_windows.pro & nmake -nologo release";
 system($cmd);
