@@ -82,7 +82,6 @@ MainWindow::MainWindow(QObject *parent)
 , selectedNumberButton(NULL)
 , regNumberSelector(NULL)
 , ciSelector(NULL)
-, dialPage(NULL)
 , statusBanner(NULL)
 , inboxDetails(NULL)
 , smsPage(NULL)
@@ -121,6 +120,16 @@ MainWindow::init()
             this, SLOT(declStatusChanged(QDeclarativeView::Status)));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
+    /*
+     * Look at the Q_INVOKABLE functions in the header and use them in QML.
+     */
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_mainwindow", this);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_inbox", &oInbox);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_contacts", &oContacts);
+
     m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
     m_view->setMainQmlFile(QLatin1String("qml/maemo/main.qml"));
     m_view->showExpanded();
@@ -210,51 +219,6 @@ MainWindow::getQMLObject(const char *pageName)
     return (pObj);
 }//MainWindow::getQMLObject
 
-bool
-MainWindow::connectToChangeNotify(QObject *item, const QString &propName,
-                                  QObject *receiver, const char *slotName)
-{
-    bool rv = false;
-    do {
-        const QMetaObject *metaObject = item->metaObject ();
-        if (NULL == metaObject) {
-            Q_WARN("NULL metaObject");
-            break;
-        }
-
-        QMetaProperty metaProp;
-        for (int i = 0; i < metaObject->propertyCount (); i++) {
-            metaProp = metaObject->property (i);
-            if (metaProp.name () == propName) {
-                rv = true;
-                break;
-            }
-        }
-
-        if (!rv) {
-            Q_WARN(QString("Couldn't find property named %1").arg(propName));
-            break;
-        }
-        rv = false;
-
-        if (!metaProp.hasNotifySignal ()) {
-            Q_WARN(QString("Property %1 does not have a notify signal")
-                   .arg(propName));
-            break;
-        }
-
-        QString signalName = QString("2%1")
-                                .arg(metaProp.notifySignal().signature());
-
-        Q_DEBUG(QString("Connect %1 to %2").arg(signalName).arg(slotName));
-
-        rv =
-        connect(item, signalName.toLatin1().constData(), receiver, slotName);
-    } while(0);
-
-    return (rv);
-}//MainWindow::connectToChangeNotify
-
 void
 MainWindow::log(QDateTime /*dt*/, int /*level*/, const QString & /*strLog*/)
 {
@@ -292,8 +256,6 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         if (NULL == loginButton) {
             break;
         }
-        connect(loginButton, SIGNAL(clicked()),
-                this, SLOT(onLoginButtonClicked()));
 
         textUsername = getQMLObject ("TextUsername");
         if (NULL == textUsername) {
@@ -372,15 +334,6 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         connect(ciSelector, SIGNAL(setCiNumber(QString,QString)),
                 &oPhones, SLOT(linkCiToNumber(QString,QString)));
 
-        dialPage = getQMLObject ("DialPage");
-        if (NULL == dialPage) {
-            break;
-        }
-        connect(dialPage, SIGNAL(sigCall(QString)),
-                this, SLOT(onUserCall(QString)));
-        //connect(dialPage, SIGNAL(sigText(QString)),
-        //        this, SLOT(onUserText(QString)));
-
         statusBanner = getQMLObject ("StatusBanner");
         if (NULL == statusBanner) {
             break;
@@ -390,8 +343,6 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         if (NULL == inboxDetails) {
             break;
         }
-        connect(inboxDetails, SIGNAL(deleteEntry(QString)),
-                &oInbox, SLOT(deleteEntry(QString)));
         connect(inboxDetails, SIGNAL(replySms(QString)),
                 this, SLOT(onUserReplyToInboxEntry(QString)));
         connect(inboxDetails, SIGNAL(play()), &oVmail, SLOT(play()));
@@ -428,29 +379,21 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         if (NULL == optContactsUpdate) {
             break;
         }
-        connect(optContactsUpdate, SIGNAL(clicked()),
-                this, SLOT(onOptContactsUpdateClicked()));
 
         optInboxUpdate = getQMLObject ("OptInboxUpdate");
         if (NULL == optInboxUpdate) {
             break;
         }
-        connect(optInboxUpdate, SIGNAL(clicked()),
-                this, SLOT(onOptInboxUpdateClicked()));
 
         edContactsUpdateFreq = getQMLObject ("EdContactsUpdateFreq");
         if (NULL == edContactsUpdateFreq) {
             break;
         }
-        connectToChangeNotify(edContactsUpdateFreq, "text",
-                              this, SLOT(onEdContactsUpdateTextChanged()));
 
         edInboxUpdateFreq = getQMLObject ("EdInboxUpdateFreq");
         if (NULL == edInboxUpdateFreq) {
             break;
         }
-        connectToChangeNotify(edInboxUpdateFreq, "text",
-                              this, SLOT(onEdInboxUpdateTextChanged()));
 
         onInitDone();
         return;
@@ -543,7 +486,6 @@ MainWindow::onUserLogoutDone()
 void
 MainWindow::uiRequestTFALoginDetails(void *ctx)
 {
-    //TODO: Make sure this looks good
     QString strPin = QInputDialog::getText(m_view, tr("Enter PIN"),
                                            tr("Two factor authentication"));
 
@@ -920,9 +862,9 @@ MainWindow::onOptInboxUpdateClicked(bool updateDb /*= true*/)
 }//MainWindow::onOptInboxUpdateClicked
 
 void
-MainWindow::onEdContactsUpdateTextChanged()
+MainWindow::onEdContactsUpdateTextChanged(const QString &text)
 {
-    quint32 mins = edContactsUpdateFreq->property ("text").toInt ();
+    quint32 mins = text.toInt ();
     if (0 == mins) {
         Q_WARN("Ignoring zero minute contact update frequency");
         return;
@@ -932,9 +874,9 @@ MainWindow::onEdContactsUpdateTextChanged()
 }//MainWindow::onEdContactsUpdateTextChanged
 
 void
-MainWindow::onEdInboxUpdateTextChanged()
+MainWindow::onEdInboxUpdateTextChanged(const QString &text)
 {
-    quint32 mins = edInboxUpdateFreq->property ("text").toInt ();
+    quint32 mins = text.toInt ();
     if (0 == mins) {
         Q_WARN("Ignoring zero minute inbox update frequency");
         return;
